# classes
Repository contenete le classi generali

# Installazione
```
pip install -e git+ssh://git@github.com/giaca95/Fastapiali-classes.git#egg=fastapiali-classes
```

# Aggiornamento su pypi
```
python setup.py bdist_wheel
twine upload --skip-existing dist/*
```